PALM-meteo: palmmeteo.utils.SliceBoolExtender Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo.utils.SliceBoolExtender Class Reference

## Public Member Functions
| __init__ (self, slice_obj, slices, boolindex)
| __getitem__ (self, key)

## Public Attributes
| slice_obj
| slices
| boolindex

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.utils.SliceBoolExtender.__init__ | ( |  | self,
|  |  | slice_obj,
|  |  | slices,
|  |  | boolindex
| ) |  |

## Member Function Documentation

## ◆ __getitem__()

palmmeteo.utils.SliceBoolExtender.__getitem__ | ( |  | self,
|  |  | key
| ) |  |

## Member Data Documentation

## ◆ boolindex

palmmeteo.utils.SliceBoolExtender.boolindex

## ◆ slice_obj

palmmeteo.utils.SliceBoolExtender.slice_obj

## ◆ slices

palmmeteo.utils.SliceBoolExtender.slices

The documentation for this class was generated from the following file:

- palmmeteo/utils.py